@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007 by Carsten Niehaus                                 *
- *   cniehaus@kde.org                                                      *
+ *   Copyright (C) 2007 by Carsten Niehaus <cniehaus@kde.org>              *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,9 +14,11 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include "legendwidget.h"
+
 #include "prefs.h"
 
 #include <kdebug.h>
@@ -26,8 +27,7 @@
 #include <QHBoxLayout>
 #include <QGridLayout>
 
-LegendWidget::LegendWidget( QWidget *parent )
-        : QWidget( parent )
+LegendWidget::LegendWidget(QWidget *parent) : QWidget(parent)
 {
     m_update = true;
     m_dockArea = Qt::BottomDockWidgetArea;
@@ -38,7 +38,7 @@ LegendWidget::~LegendWidget()
     qDeleteAll(m_legendItemList);
 }
 
-void LegendWidget::setDockArea( Qt::DockWidgetArea newDockArea )
+void LegendWidget::setDockArea(Qt::DockWidgetArea newDockArea)
 {
     kDebug() << "dock Area changed" << newDockArea;
 
@@ -65,85 +65,85 @@ void LegendWidget::updateContent()
     QList< QPair<QString, QColor> > items;
     KalziumElementProperty *elementProperty = KalziumElementProperty::instance();
     // Handle different Gradients
-    switch ( elementProperty->gradientId() ) {
+    switch (elementProperty->gradientId()) {
     case KalziumElementProperty::NOGRADIENT: // None
         break;
 
     case KalziumElementProperty::SOMGradientType:
-        items << qMakePair( elementProperty->gradient()->description(), QColor());
-        items << qMakePair( i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
-                                  "Solid" ), QColor( Prefs::color_solid() ));
+        items << qMakePair(elementProperty->gradient()->description(), QColor());
+        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
+                                  "Solid"), QColor(Prefs::color_solid()));
 
-        items << qMakePair( i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
-                                  "Liquid" ), QColor( Prefs::color_liquid() ) );
+        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
+                                  "Liquid"), QColor(Prefs::color_liquid()));
 
-        items << qMakePair( i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
-                                  "Vaporous" ), QColor( Prefs::color_vapor() ) );
+        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
+                                  "Vaporous"), QColor(Prefs::color_vapor()));
 
-        items << qMakePair( i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
-                                  "Unknown" ), QColor( Qt::lightGray ) );
+        items << qMakePair(i18nc("one of the three states of matter (solid, liquid, vaporous or unknown)",
+                                  "Unknown"), QColor(Qt::lightGray));
         break;
 
     default:
-        if (elementProperty->gradient()->logarithmicGradient())
+        if (elementProperty->gradient()->logarithmicGradient()) {
             gradientDesc = i18nc("one of the two types of gradients available", "logarithmic");
-        else
+        } else {
             gradientDesc = i18nc("one of the two types of gradients available", "linear");
-        items << qMakePair( i18n( "%1 (%2)" ,elementProperty->gradient()->description(), gradientDesc ), QColor() );
-        items << qMakePair( i18nc( "Minimum value of the gradient" ,
-                                   "Minimum: %1" , QString::number(elementProperty->gradient()->minValue()) + ' ' + elementProperty->gradient()->unit()),
-                            QColor( elementProperty->gradient()->firstColor() ));
+        }
+        items << qMakePair(i18n("%1 (%2)", elementProperty->gradient()->description(), gradientDesc), QColor());
+        items << qMakePair(i18nc("Minimum value of the gradient",
+                                   "Minimum: %1", QString::number(elementProperty->gradient()->minValue()) + ' ' + elementProperty->gradient()->unit()),
+                            QColor(elementProperty->gradient()->firstColor()));
 
-        items << qMakePair( i18nc( "Maximum value of the gradient" ,
-                                   "Maximum: %1" , QString::number(elementProperty->gradient()->maxValue()) + ' ' + elementProperty->gradient()->unit()),
-                            QColor( elementProperty->gradient()->secondColor() ));
+        items << qMakePair(i18nc("Maximum value of the gradient",
+                                   "Maximum: %1", QString::number(elementProperty->gradient()->maxValue()) + ' ' + elementProperty->gradient()->unit()),
+                            QColor(elementProperty->gradient()->secondColor()));
         break;
     }
     // schemes are always there
-    items << qMakePair( i18n( "Scheme: %1" ,elementProperty->scheme()->description() ), QColor() );
+    items << qMakePair(i18n("Scheme: %1", elementProperty->scheme()->description()), QColor());
     items << elementProperty->scheme()->legendItems();
 
-    updateLegendItemLayout( items );
+    updateLegendItemLayout(items);
 
 }
 
-void LegendWidget::updateLegendItemLayout( const QList<legendPair>& list )
+void LegendWidget::updateLegendItemLayout(const QList<legendPair>& list)
 {
-    if ( layout() ) {
+    if (layout()) {
         delete layout();
     }
-    foreach ( LegendItem * i, m_legendItemList ) {
+    foreach (LegendItem * i, m_legendItemList) {
         delete i;
     }
 
     m_legendItemList.clear();
 
-    QGridLayout * layout = new QGridLayout( this );
+    QGridLayout * layout = new QGridLayout(this);
     layout->setSpacing(0);
     layout->setMargin(0);
 
     int x = 0;
     int y = 0;
 
-    foreach ( const legendPair &pair, list )
-    {
-        LegendItem *item = new LegendItem( pair, this );
+    foreach (const legendPair &pair, list) {
+        LegendItem *item = new LegendItem(pair, this);
         m_legendItemList.append(item);
 
-        if ((m_dockArea == Qt::BottomDockWidgetArea || m_dockArea == Qt::TopDockWidgetArea) ) {
-            if ( !pair.second.isValid() ) {
-                y++;
+        if ((m_dockArea == Qt::BottomDockWidgetArea || m_dockArea == Qt::TopDockWidgetArea)) {
+            if (!pair.second.isValid()) {
+                ++y;
                 x = 0;
             }
-            if ( x >= 3) {
-                y++;
+            if (x >= 3) {
+                ++y;
                 x = 1;
             }
         }
-        layout->addWidget( item , x, y );
-        x++;
+        layout->addWidget(item, x, y);
+        ++x;
     }
-    setLayout( layout );
+    setLayout(layout);
 }
 
 void LegendWidget::legendItemAction(QColor color)
@@ -156,8 +156,8 @@ void LegendWidget::legendItemAction(QColor color)
     KalziumElementProperty *elementProperty = KalziumElementProperty::instance();
 
     for (int element = 1; element <= 118; ++element) {
-        if ( elementProperty->getBorderColor(element).operator==(color) ||
-                elementProperty->getElementColor(element).operator==(color) ) {
+        if (elementProperty->getBorderColor(element).operator==(color) ||
+                elementProperty->getElementColor(element).operator==(color)) {
             emit elementMatched(element);
         }
     }
@@ -169,7 +169,7 @@ LegendItem::LegendItem(const QPair<QString, QColor>& pair, QWidget * parent)
     QHBoxLayout *ItemLayout = new QHBoxLayout(this);
     ItemLayout->setMargin(0);
 
-    if ( pair.second.isValid() ) {
+    if (pair.second.isValid()) {
         legendItemColor = pair.second;
         connect(this, SIGNAL(legenItemHoovered(QColor)), parent, SLOT(legendItemAction(QColor)));
 
@@ -193,16 +193,14 @@ LegendItem::LegendItem(const QPair<QString, QColor>& pair, QWidget * parent)
 
 void LegendItem::enterEvent(QEvent* event)
 {
-    emit legenItemHoovered( legendItemColor );
-    QWidget::enterEvent( event );
+    emit legenItemHoovered(legendItemColor);
+    QWidget::enterEvent(event);
 }
 
 void LegendItem::leaveEvent(QEvent* event)
 {
-    emit legenItemHoovered( QColor() );
-    QWidget::leaveEvent( event );
+    emit legenItemHoovered(QColor());
+    QWidget::leaveEvent(event);
 }
 
-
 #include "legendwidget.moc"
-
